@@ -1,11 +1,12 @@
-state_codes =[
+"""List of 2-digit state codes with commented full names."""
+state_codes = [
     'al', # Alabama
     'ak', # Alaska
     'az', # Arizona
     'ar', # Arkansas
     'ca', # California
     'co', # Colorado
-    'ct', # Conneticut
+    'ct', # Connecticut
     'de', # Delaware
     'dc', # District of Columbia
     'fl', # Florida
